#!/bin/bash

if [ "$EUID" -ne 0 ]; then
  echo "Please run as root!"
  exit
fi

echo "Updating indexes"
apt update

echo "Installing xserver xinit openbox ufw xserver-xorg x11 unclutter make chromium-browser crontab cmake g++ gcc and git..."
apt install --no-install-recommends ufw xserver-xorg x11-xserver-utils xinit openbox -y || exit
apt install git gcc g++ make cmake chromium-browser unclutter iptables cron -y || exit
echo "Try to uninstall node and npm... (Can fail)"
apt purge node -y || true
apt purge npm -y || true

echo "Setup xserver..."
# XServer
echo "allowed_users=anybody" >/etc/X11/Xwrapper.config
#no-uncomment cp autostart.config /etc/xdg/openbox/autostart

echo "Adding apt keys..."
# Keys and stuff ---
# Nodejs
curl -fsSL https://deb.nodesource.com/setup_18.x | sudo -E bash

# Yarn
curl -sL https://dl.yarnpkg.com/debian/pubkey.gpg | gpg --dearmor | sudo tee /usr/share/keyrings/yarnkey.gpg >/dev/null
echo "deb [signed-by=/usr/share/keyrings/yarnkey.gpg] https://dl.yarnpkg.com/debian stable main" | sudo tee /etc/apt/sources.list.d/yarn.list

# MongoDB
wget -qO - https://www.mongodb.org/static/pgp/server-4.4.asc | sudo apt-key add -
echo "deb [ arch=amd64,arm64 ] https://repo.mongodb.org/apt/ubuntu focal/mongodb-org/4.4 multiverse" | sudo tee /etc/apt/sources.list.d/mongodb-org-4.4.list

# End Keys and stuff ---

echo "Updating firewall..."
# Firewall
ufw allow ssh
ufw allow 3000/tcp
ufw allow 3015/tcp
ufw --force enable

echo "Updating indexes and installing mongodb and yarn..."
# Final update
apt update
apt install nodejs yarn mongodb-org -y
apt upgrade -y


echo "Installing autostart..."
# Autostart
cat <<EOT >/etc/xdg/openbox/autostart
xset s off
xset s noblank
xset -dpms
setxkbmap -option terminate:ctrl_alt_bksp

# Start Chromium in kiosk mode
sed -i 's/"exited_cleanly":false/"exited_cleanly":true/' ~/.config/chromium/'Local State'
sed -i 's/"exited_cleanly":false/"exited_cleanly":true/; s/"exit_type":"[^"]\+"/"exit_type":"Normal"/' ~/.config/chromium/Default/Preferences

/usr/bin/chromium-browser --disable-infobars --kiosk --incognito --disable-pinch --overscroll-history-navigation=0 "http://127.0.0.1:3000/" &
EOT

echo "Installing bashrc"
echo "[[ -z \$DISPLAY && \$XDG_VTNR -eq 1 ]] && startx -- -nocursor" >> /home/itender/.bashrc
#
#echo "Installing start.sh"
#cat <<EOT >>/home/itender/start.sh
##!/bin/bash
#cd /home/itender/ || exit
#sed -i 's/"exited_cleanly":false/"exited_cleanly":true/' ~/.config/chromium/'Local State'
#sed -i 's/"exited_cleanly":false/"exited_cleanly":true/; s/"exit_type":"[^"]\+"/"exit_type":"Normal"/' ~/.config/chromium/Default/Preferences
#
#address="localhost"
#
#echo "Waiting 5 seconds to start chromium..."
#sleep 5
#/usr/bin/chromium-browser --disable-infobars --kiosk --incognito --disable-pinch --overscroll-history-navigation=0 "http://\${address}:3000/"
##/usr/bin/startx /usr/bin/chromium-browser --kiosk --incognito --disable-pinch --overscroll-history-navigation=0 http://192.168.1.186:3000/
#EOT
#chmod +x /home/itender/start.sh

DIR="/home/itender/itender/"
if [ -d "$DIR" ]; then
  # Take action if $DIR exists. #
  cd "$DIR" || exit
  echo "Updating..."
  git pull
else
  echo "Cloning..."
  sudo git config --global credential.helper store || exit
  git clone "https://tobiash:!IwedwrimmVeudiweN!@git.gaminggeneration.de/tobiash/itender.git" --quiet
fi
cd "$DIR" || exit
yarn install
echo "Compiling..."
yarn run compile

echo "Updating Cron..."
# Add line to cron
echo "@reboot sudo chmod g+rw /dev/tty?" > /tmp/currentCron
#echo "@reboot cd /home/itender/itender/ && /usr/bin/yarn run start &" >> /tmp/currentCron
chown itender:itender /tmp/currentCron
#install new cron file
sudo -u itender crontab /tmp/currentCron

echo "Installing systemd service..."
cat <<EOT > /etc/systemd/system/itender.service
[Unit]
Description=iTender App
After=network.target mongod.service
StartLimitIntervalSec=1
StartLimitBurst=1000

[Service]
Type=simple
Restart=always
RestartSec=1s
User=itender
ExecStartPre=sleep 3
WorkingDirectory=/home/itender/itender/
ExecStart=/usr/bin/yarn run start
StandardOutput=append:/var/log/itender.log
StandardError=append:/var/log/itender.log

[Install]
WantedBy=multi-user.target

EOT
#sh -c "git pull --quiet || true"


echo "Activating systemctl daemons..."
systemctl daemon-reload
systemctl enable mongod
systemctl enable itender

echo "Backing up /boot/config.txt to /root/config.txt.bak"
cp /boot/config.txt /root/config.txt.bak
echo "Updating Boot config..."
if ! grep -w "hdmi_group=2" /boot/config.txt; then
  echo "hdmi_group=2" >>/boot/config.txt
fi
if ! grep -w "hdmi_mode=87" /boot/config.txt; then
  echo "hdmi_mode=87" >>/boot/config.txt
fi
if ! grep -w "hdmi_cvt 1024 600 60 0 0 0 0" /boot/config.txt; then
  echo "hdmi_cvt 1024 600 60 0 0 0 0" >>/boot/config.txt
fi
if ! grep -w "hdmi_drive=1" /boot/config.txt; then
  echo "hdmi_drive=1" >>/boot/config.txt
fi
if ! grep -w "disable_splash=1" /boot/config.txt; then
  echo "disable_splash=1" >>/boot/config.txt
fi

echo "Setting no-logo..."
systemctl disable getty@tty1.service

if ! grep -w "logo.nologo" /boot/cmdline.txt; then
  echo "Backing up /boot/cmdline.txt to /root/cmdline.txt.bak"
  cp /boot/cmdline.txt /root/cmdline.txt.bak
  sed -i '1 s_$_ loglevel=3 logo.nologo disable\_splash=1 splash quiet plymouth.ignore-serial-consoles logo.nologo vt.global\_cursor_default=0_' /boot/cmdline.txt
  #cp /tmp/cmdline.txt /boot/cmdline.txt
  sed -i "1 s|$| vt.global_cursor_default=0|" /boot/cmdline.txt
  sed -i '1 i\avoid_warnings=1' /boot/config.txt
fi

chown itender:itender -R /home/itender/
adduser itender gpio

reboot now
